from setuptools import setup

setup(
    name="masonite-oauth",
    version='0.0.1',
    packages=['masonite-oauth'],
    install_requires=[
        'masonite',
    ],
    include_package_data=True,
)
